Crate plugin_test_plugins

Crate plugin_test_plugins 

Structs

English
French
PluginMetadataType
Plugins

Constants

PLUGIN_METADATA

Functions

plugins
FIXME: should return a static list of plugins FIXME: the plugin tool must know about the traits PluginInfo and the PluginMetadata from each plugin do we import them by predefined name or declare them somewhere?