Crate plugin_test_plugins
plugin_
test_
plugins
0.1.2
All Items
Crate Items
Structs
Constants
Functions
Crate
plugin_
test_
plugins
Structs

English
French
Plugin
Metadata
Type
Plugins
Constants

PLUGIN_
METADATA
Functions

plugins
FIXME: should return a static list of plugins FIXME: the plugin tool must know about the traits PluginInfo and the PluginMetadata from each plugin do we import them by predefined name or declare them somewhere?